diff -ur nagios-2.5/base/nagios.c nagios-2.5.stats/base/nagios.c
--- nagios-2.5/base/nagios.c	2006-07-13 22:57:33.000000000 +0100
+++ nagios-2.5.stats/base/nagios.c	2006-12-20 15:52:45.000000000 +0000
@@ -126,6 +126,9 @@
 time_t          last_command_status_update=0L;
 time_t          last_log_rotation=0L;
 
+int             max_command_buffer_items=0;
+int             max_service_buffer_items=0;
+
 int             use_aggressive_host_checking=DEFAULT_AGGRESSIVE_HOST_CHECKING;
 
 int             soft_state_dependencies=FALSE;
diff -ur nagios-2.5/base/utils.c nagios-2.5.stats/base/utils.c
--- nagios-2.5/base/utils.c	2006-07-13 22:55:10.000000000 +0100
+++ nagios-2.5.stats/base/utils.c	2006-12-20 15:53:01.000000000 +0000
@@ -139,6 +139,9 @@
 extern time_t	last_command_status_update;
 extern time_t   last_log_rotation;
 
+extern int      max_command_buffer_items;
+extern int      max_service_buffer_items;
+
 extern int      verify_config;
 extern int      test_scheduling;
 
@@ -4896,6 +4899,9 @@
 				if(service_result_buffer.items<SERVICE_BUFFER_SLOTS)
 					service_result_buffer.items++;
 
+				if (service_result_buffer.items > max_service_buffer_items)
+					max_service_buffer_items = service_result_buffer.items;
+
 				/* release lock on buffer */
 				pthread_mutex_unlock(&service_result_buffer.buffer_lock);
 			        }
@@ -5027,6 +5033,10 @@
 		/* increment the head counter and items */
 		external_command_buffer.head=(external_command_buffer.head + 1) % COMMAND_BUFFER_SLOTS;
 		external_command_buffer.items++;
+
+		if (external_command_buffer.items > max_command_buffer_items)
+			max_command_buffer_items = external_command_buffer.items;
+
 	        }
 
 	/* buffer was full */
@@ -5409,6 +5419,8 @@
 	last_command_check=0L;
 	last_command_status_update=0L;
 	last_log_rotation=0L;
+	max_command_buffer_items=0;
+	max_service_buffer_items=0;
 
         max_parallel_service_checks=DEFAULT_MAX_PARALLEL_SERVICE_CHECKS;
         currently_running_service_checks=0;
diff -ur nagios-2.5/include/nagios.h.in nagios-2.5.stats/include/nagios.h.in
--- nagios-2.5/include/nagios.h.in	2006-01-04 16:39:57.000000000 +0000
+++ nagios-2.5.stats/include/nagios.h.in	2006-12-19 18:02:08.000000000 +0000
@@ -479,8 +479,8 @@
 
 
 /* slots in circular buffers */
-#define COMMAND_BUFFER_SLOTS              1024
-#define SERVICE_BUFFER_SLOTS		  1024
+#define COMMAND_BUFFER_SLOTS              60000
+#define SERVICE_BUFFER_SLOTS		  60000
 
 /* worker threads */
 #define TOTAL_WORKER_THREADS              2
diff -ur nagios-2.5/xdata/xsddefault.c nagios-2.5.stats/xdata/xsddefault.c
--- nagios-2.5/xdata/xsddefault.c	2006-05-20 20:39:34.000000000 +0100
+++ nagios-2.5.stats/xdata/xsddefault.c	2006-12-20 16:58:56.720593918 +0000
@@ -86,6 +86,11 @@
 extern int process_performance_data;
 extern int aggregate_status_updates;
 
+extern int max_command_buffer_items;
+extern int max_service_buffer_items;
+extern circular_buffer external_command_buffer;
+extern circular_buffer service_result_buffer;
+
 extern char *macro_x[MACRO_X_COUNT];
 
 extern host *host_list;
@@ -346,6 +351,11 @@
 	fprintf(fp,"\tdaemon_mode=%d\n",daemon_mode);
 	fprintf(fp,"\tprogram_start=%lu\n",program_start);
 	fprintf(fp,"\tlast_command_check=%lu\n",last_command_check);
+	/* WARNING: This is not thread safe */
+	fprintf(fp,"\tcurrent_command_buffer=%d\n", external_command_buffer.items);
+	fprintf(fp,"\tmax_command_buffer_items=%d\n", max_command_buffer_items);
+	fprintf(fp,"\tcurrent_service_buffer=%d\n", service_result_buffer.items);
+	fprintf(fp,"\tmax_service_buffer_items=%d\n", max_service_buffer_items);
 	fprintf(fp,"\tlast_log_rotation=%lu\n",last_log_rotation);
 	fprintf(fp,"\tenable_notifications=%d\n",enable_notifications);
 	fprintf(fp,"\tactive_service_checks_enabled=%d\n",execute_service_checks);
